===========
What's new?
===========

zfit is still under active development and may changes frequently, staying updated is recommendable.

Recent changes in the newest version :ref:`newest-changelog`

.. toctree::
    :maxdepth: 2

    upgrade_guide
    changelog
